@@ -33,6 +33,7 @@ class AbstractInterface():
     self.indication = 'on'
     self.state = {}
     self.__config = config.get()
+    self.force_startup_mode = False
     self.pre_init()
     self.__name = self.state['name']
     self.__config_path = 'settings/%s' % (self.__name.lower())
@@ -68,8 +69,8 @@ class AbstractInterface():
 
     start_state = int(self.get_config_value('enable-on-startup'))
     self.__switch_state(start_state)
-    if start_state:
-      self.__switch_mode(self.get_modes().index(self.get_config_value('mode-on-startup')))
+    if start_state or self.force_startup_mode:
+      self.__switch_mode(self.get_modes().index(self.get_config_value('mode-on-startup')), True)
 
     #print self.__name, self.state['value'], self.state['mode'], self.state['strength']
     #self.__show_switch_dialog()
@@ -342,7 +343,8 @@ class AbstractInterface():
       if not(cmode):
         cmode = control.get_active()
       chmode = max(0, control.get_active())
-      if self.state['value'] != InterfaceState.off and chmode != self.state['mode']:
+      #if self.state['value'] != InterfaceState.off and chmode != self.state['mode']:
+      if chmode != self.state['mode']:
         try:
           self.__switch_mode(chmode)
         except:
@@ -367,17 +369,17 @@ class AbstractInterface():
     else:
       self.__processing = False
 
-  def __switch_mode(self, new_mode):
+  def __switch_mode(self, new_mode, startup=False):
     cmode = max(0, self.state['mode'])
     new_mode = max(0, min(new_mode, len(self.state['modes']) - 1))
     if new_mode != cmode:
       try:
-        self.turn_mode(new_mode)
+        self.turn_mode(new_mode, startup)
       except:
         self.switched()
         self.__update_ui()
 
-  def turn_mode(self, mode):
+  def turn_mode(self, mode, startup):
     pass
 
   def start_animation(self):
