@@ -37,6 +37,7 @@ class WLANInterface(AbstractInterface):
   def pre_init(self):
     self.__strength_timeout = None
     self.__autooff = None
+    self.force_startup_mode = True
     self.has_be = get_shell_command_output(self.wifi_cmd['check_be']) != ''
     self.state = {'name': 'WLAN',
                   'dbus': {'on': {'name': self.wifi_module_signal, 
@@ -193,11 +194,12 @@ class WLANInterface(AbstractInterface):
       gobject.source_remove(self.__strength_timeout)
       self.__strength_timeout = None
 
-  def turn_mode(self, mode):
+  def turn_mode(self, mode, startup):
     mode = min(mode, len(self.state['modes']) - 1)
     if self.state['mode'] != mode:
-      if self.state['value'] == InterfaceState.off:
-        pass
+      if self.state['value'] == InterfaceState.off or startup:
+        self.state['mode'] = mode
+        self.update()
       else:
         # down > unload > load%mode% > up
         gobject.idle_add(self.run_commands, [self.wifi_cmd['down'], self.wifi_cmd['load%s' % mode], self.wifi_cmd['up']])
